"""
Harmonizome_search_genes

Search for genes by keyword in Harmonizome (Ma'ayan Lab). Returns matching gene symbols that can ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def Harmonizome_search_genes(
    query: str,
    limit: Optional[int] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Search for genes by keyword in Harmonizome (Ma'ayan Lab). Returns matching gene symbols that can ...

    Parameters
    ----------
    query : str
        Search keyword. Examples: 'kinase', 'tumor suppressor', 'receptor'.
    limit : int
        Maximum results to return (default: 20).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {k: v for k, v in {"query": query, "limit": limit}.items() if v is not None}
    return get_shared_client().run_one_function(
        {
            "name": "Harmonizome_search_genes",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["Harmonizome_search_genes"]
